@@ -43,26 +43,25 @@ class Rethink_DBS(GeneralData):
                 dbname = self.dbname
                 dbhost = self.address[0]
                 dbport = self.address[1]
-                self.session = await self.r.connect(
-                    db=dbname,
-                    host=dbhost, port=dbport, **kwargs)
-                self.logger.info(
-                    "Connected to RethinkDB with database %s" % self.default_db)
+                self.session = await self.r.connect(db=dbname,
+                                                    host=dbhost,
+                                                    port=dbport,
+                                                    **kwargs)
+                self.logger.info("Connected to RethinkDB with database %s" %
+                                 self.default_db)
             else:
                 self.session = await self.r.connect(host=self.host,
                                                     port=self.port)
                 self.logger.info(
                     "Connected to RethinkDB without database selected")
-        except (socket.error,
-                ConnectionResetError,
+        except (socket.error, ConnectionResetError,
                 ConnectionAbortedError) as conn_error:
             msg = f'''PD_TOA_-1 + {conn_error}, ConnectionClosed rc_enu connection....'''
             self.logger.exception(kwargs["origin_exception"])
             rc = None
             raise conn_error
         except Exception as ex:
-            self.logger.exception(
-                "Excepcion al conectar a Rethinkdb %s" % ex)
+            self.logger.exception("Excepcion al conectar a Rethinkdb %s" % ex)
             raise ex
         return self.session
 
@@ -92,10 +91,10 @@ class Rethink_DBS(GeneralData):
     async def select_db(self, dbname: str = None):
         list_dbs = await self.list_dbs()
         if dbname not in list_dbs:
-            await create_db(defaultdb)
+            await self.create_db(dbname)
         if not dbname:
             result = self.session.use(self.defaultdb)
-            self.set_defaultdb(dbname, first_time=True)
+            self.set_defaultdb(self.defaultdb, first_time=True)
             self.logger.info("Set default db to use on session %s" % dbname)
             return result
         else:
@@ -107,7 +106,8 @@ class Rethink_DBS(GeneralData):
                 return "Usando %s" % dbname
             else:
                 self.logger.error(
-                    "Set default db to use on session, and database doesn\'t exists %s" % dbname)
+                    "Set default db to use on session, and database doesn\'t exists %s"
+                    % dbname)
                 result = await self.create_db(dbname)
                 return result
 
@@ -116,16 +116,17 @@ class Rethink_DBS(GeneralData):
             if not dbname and self.defaultdb:
                 dbname = self.defaultdb
             await self.list_dbs()
+            result = None
             if dbname and dbname not in self.dblist:
                 self.set_defaultdb(dbname)
                 result = await self.r.db_create(dbname).run(self.session)
                 self.logger.info("Database %s creada" % dbname)
             else:
                 result = "Database exists"
+            return result
         except Exception as e:
             print("An exception happen when try to create a database: %s" % e)
             self.logger.exception("Error al intentar crear Database %s" % e)
-        return result
 
     async def delete_db(self, dbname: str):
         self.logger.info("Delete database %s" % dbname)
@@ -149,9 +150,10 @@ class Rethink_DBS(GeneralData):
             # print("Tables by database: %s" %self.tables)
             if dbname in self.tables.keys():
                 # print("Inside create tables")
-                if not table_name in self.tables[dbname]:
+                if table_name not in self.tables[dbname]:
                     self.logger.info("Creating table named %s" % table_name)
-                    result = await self.r.db(dbname).table_create(table_name).run(self.session)
+                    result = await self.r.db(dbname).table_create(
+                        table_name).run(self.session)
                     await self.list_tables()
                     return result
                 else:
@@ -161,8 +163,7 @@ class Rethink_DBS(GeneralData):
                     return {'msg': msg}
         except Exception as e:
             self.logger.exception(
-                "Error crítico al crear tabla %s, exception" % (
-                    table_name, e))
+                "Error crítico al crear tabla %s, exception" % (table_name, e))
             raise e
 
     async def get_indexes(self, table_name: str, dbname: str = None):
@@ -171,14 +172,18 @@ class Rethink_DBS(GeneralData):
         await self.list_tables()
         await self.list_tables()
         if table_name in self.tables.get(dbname, {}):
-            indexes = await self.r.db(dbname).table(table_name).index_list().run(self.session)
+            indexes = await self.r.db(dbname).table(
+                table_name).index_list().run(self.session)
             self.index.update({table_name: indexes})
             self.logger.info("Obtaining list of indexes %s" % indexes)
             return indexes
         else:
             return []
 
-    async def create_index(self, table_name: str, index: str = None, dbname: str = None):
+    async def create_index(self,
+                           table_name: str,
+                           index: str = None,
+                           dbname: str = None):
         self.logger.info("Creating index %s on table %s" % (index, table_name))
         if not dbname:
             dbname = self.default_db
@@ -190,8 +195,10 @@ class Rethink_DBS(GeneralData):
                     self.index.update({table_name: []})
 
                 if not index in indexes:
-                    result_a = await self.r.db(dbname).table(table_name).index_create(index).run(self.session)
-                    result_b = await self.r.db(dbname).table(table_name).index_wait().run(self.session)
+                    result_a = await self.r.db(dbname).table(
+                        table_name).index_create(index).run(self.session)
+                    result_b = await self.r.db(dbname).table(
+                        table_name).index_wait().run(self.session)
                     self.index[table_name].append(index)
                     return result_a, result_b
                 else:
@@ -200,9 +207,8 @@ class Rethink_DBS(GeneralData):
                 return await self.create_table(table_name, dbname)
 
         except Exception as e:
-            self.logger.exception(
-                "Index %s can't be created %s, exception" % (index, table_name,
-                                                             e))
+            self.logger.exception("Index %s can't be created %s, exception" %
+                                  (index, table_name, e))
             raise e
 
     async def delete_table(self, table_name: str, dbname: str):
@@ -210,7 +216,8 @@ class Rethink_DBS(GeneralData):
             if table_name in self.tables[dbname]:
                 self.logger.info("Table deleted %s on database %s" %
                                  (table_name, dbname))
-                return await self.r.db(dbname).table_drop(table_name).run(self.session)
+                return await self.r.db(dbname).table_drop(table_name).run(
+                    self.session)
 
     async def list_tables(self, dbname: str = None):
         tlist = []
@@ -222,8 +229,7 @@ class Rethink_DBS(GeneralData):
         if dbname in self.dblist:
             tlist = await self.r.db(dbname).table_list().run(self.session)
             # print("Tables on database %s are %s" %(dbname, tlist))
-            self.tables.update(
-                {dbname: tlist})
+            self.tables.update({dbname: tlist})
             # print(self.tables)
         self.logger.info("Tables listed on database %s" % dbname)
         return tlist
@@ -239,10 +245,13 @@ class Rethink_DBS(GeneralData):
                 # print("Sending data %s" %data)
                 if options is None:
                     options = {'durability': 'soft', 'return_changes': False}
-                return await self.r.db(self.defaultdb).table(table_name).insert(data, **options).run(self.session, **options)
+                return await self.r.db(
+                    self.defaultdb).table(table_name).insert(
+                        data, **options).run(self.session, **options)
         except Exception as ex:
             self.logger.critical(
-                "Error in saving data on %s with data %s, error %s" % (table_name, data, ex))
+                "Error in saving data on %s with data %s, error %s" %
+                (table_name, data, ex))
             print("Error when send data %s" % ex)
             raise ex
 
@@ -254,22 +263,26 @@ class Rethink_DBS(GeneralData):
         dbname = self.defaultdb
         self.logger.info("Updating data in %s" % table_name)
         if table_name in self.tables[self.default_db]:
-            await self.r.db(dbname).table(table_name).get(id).update(conditional_data).run(self.session)
+            await self.r.db(dbname).table(table_name).get(id).update(
+                conditional_data).run(self.session)
 
     async def replace_data(self, table_name, id, conditional_data):
         dbname = self.defaultdb
         self.logger.info("Replacing data in %s" % table_name)
         if table_name in self.tables[dbname]:
-            await self.r.db(dbname).table(table_name).get(id).replace(conditional_data).run(self.session)
+            await self.r.db(dbname).table(table_name).get(id).replace(
+                conditional_data).run(self.session)
 
     async def delete_data(self, table_name, id):
         dbname = self.defaultdb
         self.logger.info("Deleting data in %s" % table_name)
         if table_name in self.tables[dbname]:
             if isinstance(id, dict):
-                await self.r.db(dbname).table(table_name).filter(id).delete().run(self.session)
+                await self.r.db(dbname).table(table_name).filter(
+                    id).delete().run(self.session)
             else:
-                await self.r.db(dbname).table(table_name).get(id).delete().run(self.session)
+                await self.r.db(dbname).table(table_name).get(id).delete().run(
+                    self.session)
 
     async def get_infoserver(self):
         self.logger.info("Get info server")
@@ -280,12 +293,14 @@ class Rethink_DBS(GeneralData):
         self.logger.info("Extracting data between %s and %s from %s" %
                          (lower, upper, table_name))
         if table_name in self.tables[self.default_db]:
-            return await self.r.db(dbname).table(table_name).between(lower, upper).run(self.session)
+            return await self.r.db(dbname).table(table_name).between(
+                lower, upper).run(self.session)
         else:
             print("No hay datos entre esos valores")
 
     async def get_data(self, table_name, index_name, value):
-        return await self.r.db(dbname).table(table_name).get_all(value, index=index_name).run(self.session)
+        return await self.r.db(dbname).table(table_name).get_all(
+            value, index=index_name).run(self.session)
 
     async def get_data_filter(self,
                               table_name,
@@ -320,27 +335,25 @@ class Rethink_DBS(GeneralData):
                     else:
                         lower = filter_exp[0]
                         upper = filter_exp[1]
-                    self.logger.info("Obtaining data from %s to %s on table %s, with filters %s using index %s" % (lower,
-                                                                                                                   upper,
-                                                                                                                   table_name,
-                                                                                                                   filter_opt,
-                                                                                                                   index))
-                    return await self.r.db(dbname).table(table_name).between(lower, upper,
-                                                                             **filter_opt).order_by(
-                        order_by).run(self.session, **options)
+                    self.logger.info(
+                        "Obtaining data from %s to %s on table %s, with filters %s using index %s"
+                        % (lower, upper, table_name, filter_opt, index))
+                    return await self.r.db(dbname).table(table_name).between(
+                        lower, upper, **filter_opt).order_by(order_by).run(
+                            self.session, **options)
                 else:
-                    self.logger.info("Obtaining data with filters %s using table %s" % (
-                        filter_opt, table_name))
+                    self.logger.info(
+                        "Obtaining data with filters %s using table %s" %
+                        (filter_opt, table_name))
 
                     return await self.r.db(dbname).table(table_name).filter(
-                        filter_exp).order_by(
-                        order_by).run(
-                        self.session, **options)
+                        filter_exp).order_by(order_by).run(
+                            self.session, **options)
             else:
                 return []
         except Exception as ec:
-            self.logger.exception(
-                "Error on the data extraction, error %s" % ec)
+            self.logger.exception("Error on the data extraction, error %s" %
+                                  ec)
             await asyncio.sleep(5)
             await self.reconnect(wait=True)
             raise ec
